"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Ajv = require("ajv");
const chai_1 = require("chai");
const fs_1 = require("fs");
const path_1 = require("path");
const formatter_1 = require("../factory/formatter");
const parser_1 = require("../factory/parser");
const program_1 = require("../factory/program");
const SchemaGenerator_1 = require("../src/SchemaGenerator");
const validator = new Ajv();
const metaSchema = require("ajv/lib/refs/json-schema-draft-06.json");
validator.addMetaSchema(metaSchema);
const basePath = "test/valid-data";
function assertSchema(name, type, only = false) {
    const run = only ? it.only : it;
    run(name, () => {
        const config = {
            path: path_1.resolve(`${basePath}/${name}/*.ts`),
            type: type,
            expose: "export",
            topRef: true,
            jsDoc: "none",
        };
        const program = program_1.createProgram(config);
        const generator = new SchemaGenerator_1.SchemaGenerator(program, parser_1.createParser(program, config), formatter_1.createFormatter(config));
        const schema = generator.createSchema(type);
        const expected = JSON.parse(fs_1.readFileSync(path_1.resolve(`${basePath}/${name}/schema.json`), "utf8"));
        const actual = JSON.parse(JSON.stringify(schema));
        chai_1.assert.isObject(actual);
        chai_1.assert.deepEqual(actual, expected);
        validator.validateSchema(actual);
        chai_1.assert.isNull(validator.errors);
    });
}
describe("valid-data", () => {
    assertSchema("simple-object", "SimpleObject");
    assertSchema("interface-single", "MyObject");
    assertSchema("interface-multi", "MyObject");
    assertSchema("interface-recursion", "MyObject");
    assertSchema("interface-extra-props", "MyObject");
    assertSchema("structure-private", "MyObject");
    assertSchema("structure-anonymous", "MyObject");
    assertSchema("structure-recursion", "MyObject");
    assertSchema("structure-extra-props", "MyObject");
    assertSchema("enums-string", "Enum");
    assertSchema("enums-number", "Enum");
    assertSchema("enums-initialized", "Enum");
    assertSchema("enums-compute", "Enum");
    assertSchema("enums-mixed", "Enum");
    assertSchema("enums-member", "MyObject");
    assertSchema("string-literals", "MyObject");
    assertSchema("string-literals-inline", "MyObject");
    assertSchema("string-literals-null", "MyObject");
    assertSchema("namespace-deep-1", "RootNamespace.Def");
    assertSchema("namespace-deep-2", "RootNamespace.SubNamespace.HelperA");
    assertSchema("namespace-deep-3", "RootNamespace.SubNamespace.HelperB");
    assertSchema("import-simple", "MyObject");
    assertSchema("import-exposed", "MyObject");
    assertSchema("import-anonymous", "MyObject");
    assertSchema("type-aliases-primitive", "MyString");
    assertSchema("type-aliases-object", "MyAlias");
    assertSchema("type-aliases-mixed", "MyObject");
    assertSchema("type-aliases-union", "MyUnion");
    assertSchema("type-aliases-anonymous", "MyObject");
    assertSchema("type-aliases-local-namespace", "MyObject");
    assertSchema("type-aliases-recursive-anonymous", "MyAlias");
    assertSchema("type-aliases-recursive-export", "MyObject");
    assertSchema("type-aliases-tuple", "MyTuple");
    assertSchema("type-aliases-tuple-empty", "MyTuple");
    assertSchema("type-aliases-tuple-optional-items", "MyTuple");
    assertSchema("type-aliases-tuple-rest", "MyTuple");
    assertSchema("type-aliases-tuple-only-rest", "MyTuple");
    assertSchema("type-maps", "MyObject");
    assertSchema("type-primitives", "MyObject");
    assertSchema("type-union", "TypeUnion");
    assertSchema("type-union-tagged", "Shape");
    assertSchema("type-intersection", "MyObject");
    assertSchema("type-intersection-additional-props", "MyObject");
    assertSchema("type-typeof", "MyType");
    assertSchema("type-typeof-value", "MyType");
    assertSchema("type-indexed-access-tuple-1", "MyType");
    assertSchema("type-indexed-access-tuple-2", "MyType");
    assertSchema("type-indexed-access-object-1", "MyType");
    assertSchema("type-indexed-access-object-2", "MyType");
    assertSchema("type-keyof-tuple", "MyType");
    assertSchema("type-keyof-object", "MyType");
    assertSchema("type-mapped-simple", "MyObject");
    assertSchema("type-mapped-index", "MyObject");
    assertSchema("type-mapped-literal", "MyObject");
    assertSchema("type-mapped-generic", "MyObject");
    assertSchema("type-mapped-native", "MyObject");
    assertSchema("type-mapped-native-single-literal", "MyObject");
    assertSchema("type-mapped-widened", "MyObject");
    assertSchema("generic-simple", "MyObject");
    assertSchema("generic-arrays", "MyObject");
    assertSchema("generic-multiple", "MyObject");
    assertSchema("generic-multiargs", "MyObject");
    assertSchema("generic-anonymous", "MyObject");
    assertSchema("generic-recursive", "MyObject");
    assertSchema("generic-hell", "MyObject");
    assertSchema("generic-default", "MyObject");
    assertSchema("nullable-null", "MyObject");
    assertSchema("undefined-alias", "MyType");
    assertSchema("undefined-union", "MyType");
    assertSchema("undefined-property", "MyType");
    assertSchema("any-unknown", "MyObject");
});
//# sourceMappingURL=valid-data.test.js.map